from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceOnlineEventStreamType, CommentType, EventFilterSeveritiesItem, FocusedDatapoint, DeviceOfflineEventMetadata, CommandDeliveryEventStreamType, InterventionRequestType, Annotation, SystemEventMetadata, StatefulEventStreamType, CommentMetadata, TaskSummaryTags, TeleopSessionRecordStreamType, CustomEventMetadata, CommentTags, DeviceOfflineEventType, StatefulEventTags, EventHistogram, InterventionRequestMetadata, AnnotationMetadata, TeleopSessionRecordTags, PortForwardingSessionRecordTags, PortForwardingSessionRecordStreamType, SystemEvent, DeviceOfflineEventTags, CommandDeliveryEventMetadata, DeviceOnlineEventType, EventSeekQuery, TaskSummary, DeviceOnlineEvent, EventSort, TaskSummaryStreamType, StatefulEvent, DatapointEventTags, CustomEvent, EventSortColumn, InterventionRequestTags, TeleopSessionRecord, InterventionRequestInterventionType, DeviceOfflineEvent, EventQueryEventTypesItem, CommandDeliveryEvent, SystemEventStreamType, TaskSummaryMetadata, PhysicalRequestData, EventSeekQueryTypesItem, EventCounts, DatapointEventStreamType, TeleopSessionRecordMetadata, DeviceOfflineEventSeverity, DeviceOnlineEventMetadata, InterventionRequestSeverity, EventFilterEventTypesItem, DatapointEventType, InterventionRequestStreamType, EventHistogramEntry, CustomEventSeverity, AnnotationType, SelectionRequestData, CustomEventStreamType, EventQuerySeveritiesItem, TaskSummaryType, LabeledPolygon, EventExportSheetResult, PortForwardingSessionRecord, PortForwardingSessionRecordType, EventListResponse, EventExportSheetRequest, SystemEventTags, DatapointEvent, StatefulEventSeverity, SystemEventType, StatefulEventType, EventQuery, AnnotationTags, DeviceOfflineEventStreamType, AnnotationStreamType, DatapointEventMetadata, EventFilterTypesItem, EventTriggerCommand, EventSeekQueryDirection, Label, CommandDeliveryEventTags, CustomEventType, EventSeekQuerySeveritiesItem, PortForwardingSessionRecordMetadata, CommentStreamType, DatapointEventSeverity, TaskSummaryReport, TeleopSessionRecordType, EventFilter, EventQueryTypesItem, StatefulEventMetadata, DeviceOnlineEventTags, LabelingRequestData, CommandDeliveryEventType, CustomEventTags, DeviceOnlineEventSeverity, TeleopRequestData, EventSortOrder, EventSeekQueryEventTypesItem, InterventionRequest, Comment
from formant.sdk.cloud.v2.formant_admin_api_client.api.event import event_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *


from formant.sdk.cloud.v2.formant_admin_api_client.models import ScopeFilterTypesItem, AnnotationFieldType, AnnotationTags, AnnotationFieldValuesRequest, AnnotationStreamType, ScopeFilter, FocusedDatapoint, AnnotationType, Annotation, AnnotationFieldValuesResponse, AnnotationTemplateTags, TagParameters, AnnotationTemplate, UserParameters, AnnotationFieldValueTags, AnnotationField, UserParametersRolesItem, AnnotationTemplateListResponse, AnnotationFieldValuesRequestTags, AnnotationMetadata, SheetParameters, AnnotationFieldValue
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation import annotation_controller_post
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation_template import annotation_template_controller_list, annotation_template_controller_get_one
from formant.sdk.cloud.v2.formant_admin_api_client.types import *


from formant.sdk.cloud.v2.formant_query_api_client.models import Path, QueryTypesItem, StreamDataTags, StreamDataPointsItem, Odometry, Twist, NumericSetEntry, ImageAnnotation, Map, Localization, Health, StreamAggregateDataTags, HealthStatus, StreamDataListResponse, Battery, StreamDataType, TransformNode, StreamAggregateData, Bitset, Goal, BoundingBox, StreamAggregateDataType, File, Health,HealthStatus, Quaternion, Location, PointCloud, Transform, Image, Query, Video, VideoMimeType, Vector3, QueryAggregate, StreamData, Video,VideoMimeType
from formant.sdk.cloud.v2.formant_query_api_client.api.query import query_controller_query
from formant.sdk.cloud.v2.formant_query_api_client.types import *


from formant.sdk.cloud.v2.formant_admin_api_client.models import AdapterConfiguration, Adapter, AdapterCascadingConfigurationSpecificity, AdapterListResponse, AdapterCascadingConfiguration, AdapterCascadingConfigurationType
from formant.sdk.cloud.v2.formant_admin_api_client.api.adapter import adapter_controller_post, adapter_controller_delete
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from typing import Any


from formant.sdk.cloud.v2.formant_admin_api_client.models import ViewConfiguration, View, ViewLayoutType, ImageViewConfiguration, PartialViewTags, ViewListResponse, PointCloudViewConfiguration, LocationViewport, BitsetViewConfiguration, TransformTreeViewConfiguration, Location, PartialViewLayoutType, LocalizationViewConfiguration, Filter, PartialView, ImageViewConfigurationMode, ViewTags, NumericViewConfiguration, ViewConfigurationType, LocationViewConfiguration, Camera, Vector3, LocationViewConfigurationBasemap
from formant.sdk.cloud.v2.formant_admin_api_client.api.view import view_controller_get_one, view_controller_get_all, view_controller_patch
from formant.sdk.cloud.v2.formant_admin_api_client.types import *


from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="RefreshRequest")


@attr.s(auto_attribs=True)
class RefreshRequest:
    """
    Attributes:
        refresh_token (str):
        token_expiration_seconds (Union[Unset, int]):
    """

    refresh_token: str
    token_expiration_seconds: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        refresh_token = self.refresh_token
        token_expiration_seconds = self.token_expiration_seconds

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "refreshToken": refresh_token,
            }
        )
        if token_expiration_seconds is not UNSET:
            field_dict["tokenExpirationSeconds"] = token_expiration_seconds

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        refresh_token = d.pop("refreshToken")

        token_expiration_seconds = d.pop("tokenExpirationSeconds", UNSET)

        refresh_request = cls(
            refresh_token=refresh_token,
            token_expiration_seconds=token_expiration_seconds,
        )

        refresh_request.additional_properties = d
        return refresh_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceOnlineEventStreamType, DeviceDetailsSortOrder, DeviceRosState, DeviceDiagnosticsConfiguration, ScopeFilter, DeviceTeleopRosStreamConfigurationMode, DeviceStreamDirectoryWatchConfigurationFileType, DeviceOfflineEventMetadata, RtcInfoRtcIceTransportPoliciesItem, CommandProgress, DeviceState, DeviceRosConfiguration, DeviceTeleopRosStreamConfiguration, DeviceStreamRosLocalizationConfiguration, OnDemandState, DeviceFollower, DeviceTags, DeviceTelemetryConfiguration, DeviceApplicationConfiguration, TeleopJoystickConfiguration, DeviceStreamDirectoryWatchConfigurationType, OnvifDevice, DeviceOfflineEventType, DeviceStreamCustomConfiguration, DeviceReportedConfigurationState, PartialDeviceType, DeviceStreamConfigurationQuality, DeviceDiskConfiguration, TeleopJoystickAxisConfiguration, DeviceStreamFileTailConfiguration, NetworkInfo, DeviceStreamFileTailConfigurationType, NodeInfo, OnDemandPresenceTimeRange, DeviceRealtimeConfiguration, DeviceTeleopCustomStreamConfigurationQuality, DeviceStreamRosTopicConfigurationRosVersion, DeviceConfiguration, OnDemandPresenceStreamItemGroup, DeviceOfflineEventTags, DeviceStreamHardwareConfigurationQuality, DeviceOnlineEventType, AdapterConfiguration, DeviceTeleopRosStreamConfigurationNumericControlVisualization, DeviceConfigurationTemplate, DeviceStreamHardwareConfigurationType, DeviceTeleopRosStreamConfigurationTopicType, OnDemandStreamPresence, DeviceOnlineEvent, DeviceTeleopHardwareStreamConfiguration, DeviceTeleopRosStreamConfigurationRosVersion, DeviceTeleopHardwareStreamConfigurationHardwareType, DeviceStreamHardwareConfiguration, DeviceTeleopHardwareStreamConfigurationRtcStreamType, DeviceTeleopRosStreamConfigurationAudioCodec, TeleopViewConfiguration, PartialDeviceTags, OnDemandPresenceStreamItemGroupDatapointType, DeviceTeleopConfiguration, DeviceDetailsType, DeviceStreamConfiguration, DeviceTeleopHardwareStreamConfigurationQuality, DeviceOfflineEvent, AudioDevice, ValidationConfiguration, DeviceStreamFileTailConfigurationFileFormat, DeviceProvisioningRequest, DeviceStreamHardwareConfigurationHardwareType, DeviceScope, ScopeFilterTypesItem, RosTopic, DeviceDetailsSort, RtcInfo, OsInfo, DeviceConfigurationTemplateTags, DeviceTeleopCustomStreamConfiguration, DeviceStreamRosLocalizationConfigurationType, DeviceOfflineEventSeverity, Device, DeviceOnlineEventMetadata, DeviceDetails, DeviceStreamTransformConfiguration, DeviceTeleopCustomStreamConfigurationNumericControlVisualization, DeviceConfigurationDocument, DeviceCredentials, TeleopJoystickConfigurationPosition, DeviceConfigurationDocumentTags, DeviceTeleopRosStreamConfigurationQuality, OnDemandBuffer, DeviceQueryType, DeviceQuery, DeviceTeleopCustomStreamConfigurationMode, DeviceBlobData, DeviceProvisioning, DeviceResourcesConfiguration, DeviceStreamRosTopicConfiguration, DeviceTeleopHardwareStreamConfigurationMode, VideoDevice, RtcInfoRtcIceServerProtocol, DeviceDetailsTags, DeviceType, DeviceStreamRosTransformTreeConfigurationType, PartialDevice, DeviceStreamRosTransformTreeConfigurationRosVersion, DeviceOfflineEventStreamType, DeviceStreamConfigurationTags, DeviceListResponse, DeviceConfigurationTemplateListResponse, DeviceDetailsSortColumn, DeviceStreamRosLocalizationConfigurationRosVersion, Network, HwInfo, DeviceStreamRosTransformTreeConfiguration, DeviceStreamDirectoryWatchConfiguration, DeviceStreamCustomConfigurationType, DeviceApplicationConfigurationConfigurationMap, DeviceDetailsListResponse, DeviceTeleopCustomStreamConfigurationRtcStreamType, OnDemandBufferBufferType, DeviceOnlineEventTags, TeleopJoystickAxisConfigurationDimension, DeviceStreamRosTopicConfigurationType, DeviceScopeTypesItem, DeviceOnlineEventSeverity, KernelInfo, DevicePortForwardingConfiguration, DeviceStateEnv
from formant.sdk.cloud.v2.formant_admin_api_client.api.device import device_controller_query, device_controller_patch, device_controller_get_one, device_controller_get_configuration, device_controller_post_configuration
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from formant.sdk.cloud.v2.formant_admin_api_client.types import Optional


from formant.sdk.cloud.v2.formant_admin_api_client.models import ScopeFilterTypesItem, CommandTemplateParameterMeta, Command, CommandDeliveryEventMetadata, CommandTemplateTags, ScopeFilter, CommandTemplateListResponse, CommandRequestListResponse, CommandDeliveryEventStreamType, CommandProgress, CommandDeliveryEventTags, CommandParameter, CommandResponseStreamType, CommandResponseTags, CommandTemplate, CommandTags, FileInfo, Filter, CommandParameterMeta, CommandDeliveryEventType, CommandRequest, CommandResponse, CommandDeliveryEvent, CommandListResponse, CommandQuery, CommandStreamType
from formant.sdk.cloud.v2.formant_admin_api_client.api.command import command_controller_post, command_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *